miq_version
========

Introduction
------------

A class that ensures correct sorting and parsing of the ManageIQ/CFME version numbers

Usage
-----

.. code-block:: python

  from miq_version import Version

  Version('5.4.2.0')
